@@ -1,13 +1,16 @@
-//! A highly customizable changelog generator
+//! A highly customizable changelog generator ⛰️
+//!
+//! The crate provides a set of optional features that can be enabled in your
+//! `Cargo.toml` file.
 //!
 //! ## Features
-//!
-//! The [cargo features](https://doc.rust-lang.org/cargo/reference/features.html)
-//! of the library are:
-//! - `repo`: Enable parsing commits from a git repository. Enabled by default.
-//!   You can turn this off if you already have the commits to put in the
-//!   changelog and you don't need `git-cliff` to parse them.
+#![cfg_attr(feature = "document-features", doc = document_features::document_features!())]
+#![cfg_attr(docsrs, feature(doc_auto_cfg))]
 #![warn(missing_docs, clippy::unwrap_used)]
+#![doc(
+	html_logo_url = "https://raw.githubusercontent.com/orhun/git-cliff/main/website/static/img/git-cliff.png",
+	html_favicon_url = "https://raw.githubusercontent.com/orhun/git-cliff/main/website/static/favicon/favicon.ico"
+)]
 
 /// Changelog generator.
 pub mod changelog;
