@@ -19,6 +19,6 @@ fn main() -> Result<()> {
 	let mut buffer = Vec::<u8>::new();
 	man.render(&mut buffer)?;
 	fs::write(&out_path, buffer)?;
-	println!("Man page is generated at {:?}", out_path);
+	println!("Man page is generated at {out_path:?}");
 	Ok(())
 }
